#!/bin/ksh 
# @(#)91  1.1 src/cmdline/staging/examples/test_import_all.sh, amws.cmdline, fim611, 060808b 5/4/06 18:48:23
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# This script demonstrates how to transfer a set of FIM
# federations and partners from one domain to another.
# It assumes you have completed the following steps:
# 1. exported the FIM archive from your source environment
# 2. edited the source domain file ($source_domain)
#    to include the appropriate connection properties and 
#    temporary FIM domain name.
# 3. edited the target domain file ($target_domain)
#    to include the appropriate connection properties for 
#    your target FIM domain name.

basedir=/opt/IBM/FIM/tools/staging
scriptdir=$basedir/scripts
exampledir=$basedir/examples
bindir=$basedir/bin
fimadmin=$bindir/FIMAdmin_no_was_sec.sh
source_domain=$exampledir/source.properties
target_domain=$exampledir/target.properties
ip_archive=$exampledir/ip.jar
sp_archive=$exampledir/sp.jar
archive_file=$ip_archive
data_dir=/tmp/data_dir

# Introduction
print "This script demonstrates how to transfer a set of FIM"
print "federations and partners from one domain to another."
print "It assumes you have completed the following steps:"
print "1. exported the FIM archive from your source environment"
print "2. edited the source domain file \n   ($source_domain)"
print "   to include the appropriate connection properties and "
print "   temporary FIM domain name."
print "3. edited the target domain file \n   ($target_domain)"
print "   to include the appropriate connection properties for "
print "   your target FIM domain name."
print "Press the Enter key to continue or Cntl-C to quit"
read

# Change directory to the location of the scripts
cd $scriptdir
if [[ ! -a $data_dir ]]; then
   mkdir $data_dir
fi

# Clean up by deleting the staging domain
print "Executing the following FIM script:"
print "$fimadmin delete_domain.py $source_domain\n"
$fimadmin delete_domain.py $source_domain

# The following command:
#    1. creates a new FIM domain based on the domain name found 
#	in the $source_domain file 
#    2. imports the FIM archive ($archive_file) into 
#	staging domain
#    3. creates the $data_dir and populates it with properties files
#	containing the properties of all federations and partners
# 	in the staging domain.
print "Executing the following FIM script:"
print "$fimadmin generate_import_properties.py $source_domain $data_dir $archive_file\n"
$fimadmin generate_import_properties.py $source_domain $data_dir $archive_file 

# Pause to allow user to modify properties files in the data directory
print "You may press the Enter key now if you do not need"
print "to modify any federation or partner properties before importing."
print "Otherwise, if you want to change federation or partner properties, "
print "you must edit the files in the data directory"
print "($data_dir).\nWhen finished, come back to this window"
print "and press the Enter key to continue..."
read

# The following command:
#    1. reads in the file $data_dir/_import.properties and uses it 
#	to determine which federations and partners to import
#    2. for each federation and partner listed in $data_dir/_import.properties,
#	import the object with the values specified in the associated objects
#	properties file.
print "Executing the following FIM script:"
print "$fimadmin import_federations_and_partners.py $source_domain $target_domain $data_dir\n"
$fimadmin import_federations_and_partners.py $source_domain $target_domain $data_dir
